HistogramLUTWidget — pyqtgraph 0.11.0rc0 documentation

# HistogramLUTWidget

class `pyqtgraph.` `HistogramLUTWidget`(parent=None, *args, **kargs)
  `__init__`(parent=None, *args, **kargs)

    Arguments: |
    parent | Optional parent widget
    useOpenGL | If True, the GraphicsView will use OpenGL to do all of its rendering. This can improve performance on some systems, but may also introduce bugs (the combination of QGraphicsView and QGLWidget is still an ‘experimental’ feature of Qt)
    background | Set the background color of the GraphicsView. Accepts any single argument accepted by `mkColor`. By default, the background color is determined using the ‘backgroundColor’ configuration option (see `setConfigOptions`).

  `sizeHint`(self) → PySide2.QtCore.QSize